=======
Credits
=======

Development Lead
----------------

* **Johannes Grün** <gruen@uni-bonn.de>

Contributors
------------

* **Michael Ankele** - *Constrained spherical deconvolution with tensor fODFs* - [momentarylapse] (https://github.com/momentarylapse)

* **Johannes Grün** - *Fiber tracking with spatial regularization or model averaging* - [JoGruen] (https://github.com/JoGruen)

* **Olivier Morelle** - *Code curation, documentation and testing* [Oli4] (https://github.com/Oli4)

* **Thomas Schultz** - *DKI fitting, supervision and contributions throughout* - [ThomasSchultz] (https://github.com/ThomasSchultz)
